
## Retention

Retention is a simple tool to calculate and plot app retention related data

## Installation

Please make sure your Python is v3.7 or above, as it's required by Matplotlib 3.4 for plottting.

```bash
python3 --version
python3 -m pip install retention
```

Or, clone from GitHub:
```bash
git clone https://github.com/floatinghotpot/retention.git
cd retention
python3 -m pip install -e .
```

## How to Use
```bash
retention sample1.csv
```

![Draw stock](https://github.com/floatinghotpot/retention/raw/main/docs/sample.png)
